@@ -1,13 +1,13 @@
 /*
  * should.js - assertion library
  * Copyright(c) 2010-2013 TJ Holowaychuk <tj@vision-media.ca>
- * Copyright(c) 2013-2016 Denis Bardadym <bardadymchik@gmail.com>
+ * Copyright(c) 2013-2017 Denis Bardadym <bardadymchik@gmail.com>
  * MIT Licensed
  */
 
-module.exports = function(should, Assertion) {
+export default function(should, Assertion) {
   /**
-   * Simple chaining. It actually do nothing.
+   * Simple chaining to improve readability. Does nothing.
    *
    * @memberOf Assertion
    * @name be
@@ -16,6 +16,7 @@ module.exports = function(should, Assertion) {
    * @alias Assertion#of
    * @alias Assertion#a
    * @alias Assertion#and
+   * @alias Assertion#been
    * @alias Assertion#have
    * @alias Assertion#has
    * @alias Assertion#with
@@ -25,7 +26,21 @@ module.exports = function(should, Assertion) {
    * @alias Assertion#it
    * @category assertion chaining
    */
-  ['an', 'of', 'a', 'and', 'be', 'has', 'have', 'with', 'is', 'which', 'the', 'it'].forEach(function(name) {
+  [
+    "an",
+    "of",
+    "a",
+    "and",
+    "be",
+    "been",
+    "has",
+    "have",
+    "with",
+    "is",
+    "which",
+    "the",
+    "it"
+  ].forEach(function(name) {
     Assertion.addChain(name);
   });
-};
+}
