@@ -1,12 +1,13 @@
 /*
  * should.js - assertion library
  * Copyright(c) 2010-2013 TJ Holowaychuk <tj@vision-media.ca>
- * Copyright(c) 2013-2016 Denis Bardadym <bardadymchik@gmail.com>
+ * Copyright(c) 2013-2017 Denis Bardadym <bardadymchik@gmail.com>
  * MIT Licensed
  */
-var util = require('../util');
+import { isIterator, isGeneratorFunction } from "should-util";
+import { functionName } from "../util";
 
-module.exports = function(should, Assertion) {
+export default function(should, Assertion) {
   var i = should.format;
 
   /**
@@ -33,15 +34,15 @@ module.exports = function(should, Assertion) {
    *   yield throwError();
    * }).should.throw();
    */
-  Assertion.add('throw', function(message, properties) {
+  Assertion.add("throw", function(message, properties) {
     var fn = this.obj;
     var err = {};
-    var errorInfo = '';
+    var errorInfo = "";
     var thrown = false;
 
-    if (util.isGeneratorFunction(fn)) {
+    if (isGeneratorFunction(fn)) {
       return should(fn()).throw(message, properties);
-    } else if (util.isGeneratorObject(fn)) {
+    } else if (isIterator(fn)) {
       return should(fn.next.bind(fn)).throw(message, properties);
     }
 
@@ -58,11 +59,11 @@ module.exports = function(should, Assertion) {
 
     if (thrown) {
       if (message) {
-        if ('string' == typeof message) {
+        if ("string" == typeof message) {
           errorMatched = message == err.message;
         } else if (message instanceof RegExp) {
           errorMatched = message.test(err.message);
-        } else if ('function' == typeof message) {
+        } else if ("function" == typeof message) {
           errorMatched = err instanceof message;
         } else if (null != message) {
           try {
@@ -78,12 +79,21 @@ module.exports = function(should, Assertion) {
         }
 
         if (!errorMatched) {
-          if ('string' == typeof message || message instanceof RegExp) {
-            errorInfo = " with a message matching " + i(message) + ", but got '" + err.message + "'";
-          } else if ('function' == typeof message) {
-            errorInfo = " of type " + util.functionName(message) + ", but got " + util.functionName(err.constructor);
+          if ("string" == typeof message || message instanceof RegExp) {
+            errorInfo =
+              " with a message matching " +
+              i(message) +
+              ", but got '" +
+              err.message +
+              "'";
+          } else if ("function" == typeof message) {
+            errorInfo =
+              " of type " +
+              functionName(message) +
+              ", but got " +
+              functionName(err.constructor);
           }
-        } else if ('function' == typeof message && properties) {
+        } else if ("function" == typeof message && properties) {
           try {
             should(err).match(properties);
           } catch (e) {
@@ -100,11 +110,11 @@ module.exports = function(should, Assertion) {
       }
     }
 
-    this.params = { operator: 'to throw exception' + errorInfo };
+    this.params = { operator: "to throw exception" + errorInfo };
 
     this.assert(thrown);
     this.assert(errorMatched);
   });
 
-  Assertion.alias('throw', 'throwError');
-};
+  Assertion.alias("throw", "throwError");
+}
