@@ -1,14 +1,16 @@
 /*
  * should.js - assertion library
  * Copyright(c) 2010-2013 TJ Holowaychuk <tj@vision-media.ca>
- * Copyright(c) 2013-2016 Denis Bardadym <bardadymchik@gmail.com>
+ * Copyright(c) 2013-2017 Denis Bardadym <bardadymchik@gmail.com>
  * MIT Licensed
  */
 
-var util = require('../util');
-var eql = require('should-equal');
+import { formatProp } from "../format";
+import { some, forEach } from "should-type-adaptors";
+import eql from "should-equal";
+import { isPlainObject } from "../util";
 
-module.exports = function(should, Assertion) {
+export default function(should, Assertion) {
   var i = should.format;
 
   /**
@@ -67,68 +69,81 @@ module.exports = function(should, Assertion) {
    * (new Error('boom')).should.match(/abc/);//passed because no keys
    * (new Error('boom')).should.not.match({ message: /abc/ });//check specified property
    */
-  Assertion.add('match', function(other, description) {
-    this.params = {operator: 'to match ' + i(other), message: description};
+  Assertion.add("match", function(other, description) {
+    this.params = { operator: "to match " + i(other), message: description };
 
-    if (!eql(this.obj, other).result) {
-      if (other instanceof RegExp) { // something - regex
-
-        if (typeof this.obj == 'string') {
+    if (eql(this.obj, other).length !== 0) {
+      if (other instanceof RegExp) {
+        // something - regex
 
+        if (typeof this.obj == "string") {
           this.assert(other.exec(this.obj));
-        } else if (util.isIndexable(this.obj)) {
-          util.forEach(this.obj, function(item) {
-            this.assert(other.exec(item));// should we try to convert to String and exec?
-          }, this);
-        } else if (null != this.obj && typeof this.obj == 'object') {
+        } else if (null != this.obj && typeof this.obj == "object") {
+          var notMatchedProps = [],
+            matchedProps = [];
+          forEach(
+            this.obj,
+            function(value, name) {
+              if (other.exec(value)) {
+                matchedProps.push(formatProp(name));
+              } else {
+                notMatchedProps.push(formatProp(name) + " (" + i(value) + ")");
+              }
+            },
+            this
+          );
 
-          var notMatchedProps = [], matchedProps = [];
-          util.forEach(this.obj, function(value, name) {
-            if (other.exec(value)) matchedProps.push(util.formatProp(name));
-            else notMatchedProps.push(util.formatProp(name) + ' (' + i(value) + ')');
-          }, this);
-
-          if (notMatchedProps.length)
-            this.params.operator += '\n    not matched properties: ' + notMatchedProps.join(', ');
-          if (matchedProps.length)
-            this.params.operator += '\n    matched properties: ' + matchedProps.join(', ');
+          if (notMatchedProps.length) {
+            this.params.operator += "\n    not matched properties: " + notMatchedProps.join(", ");
+          }
+          if (matchedProps.length) {
+            this.params.operator += "\n    matched properties: " + matchedProps.join(", ");
+          }
 
           this.assert(notMatchedProps.length === 0);
-        } // should we try to convert to String and exec?
-      } else if (typeof other == 'function') {
+        } else {
+          // should we try to convert to String and exec?
+          this.assert(false);
+        }
+      } else if (typeof other == "function") {
         var res;
 
         res = other(this.obj);
 
-        //if(res instanceof Assertion) {
-        //  this.params.operator += '\n    ' + res.getMessage();
-        //}
-
         //if we throw exception ok - it is used .should inside
-        if (typeof res == 'boolean') {
+        if (typeof res == "boolean") {
           this.assert(res); // if it is just boolean function assert on it
         }
-      } else if (other != null && this.obj != null && typeof other == 'object' && typeof this.obj == 'object') { // try to match properties (for Object and Array)
+      } else if (typeof this.obj == "object" && this.obj != null && (isPlainObject(other) || Array.isArray(other))) {
+        // try to match properties (for Object and Array)
         notMatchedProps = [];
         matchedProps = [];
 
-        util.forEach(other, function(value, key) {
-          try {
-            should(this.obj).have.property(key).which.match(value);
-            matchedProps.push(util.formatProp(key));
-          } catch (e) {
-            if (e instanceof should.AssertionError) {
-              notMatchedProps.push(util.formatProp(key) + ' (' + i(this.obj[key]) + ')');
-            } else {
-              throw e;
+        forEach(
+          other,
+          function(value, key) {
+            try {
+              should(this.obj)
+                .have.property(key)
+                .which.match(value);
+              matchedProps.push(formatProp(key));
+            } catch (e) {
+              if (e instanceof should.AssertionError) {
+                notMatchedProps.push(formatProp(key) + " (" + i(this.obj[key]) + ")");
+              } else {
+                throw e;
+              }
             }
-          }
-        }, this);
+          },
+          this
+        );
 
-        if (notMatchedProps.length)
-          this.params.operator += '\n    not matched properties: ' + notMatchedProps.join(', ');
-        if (matchedProps.length)
-          this.params.operator += '\n    matched properties: ' + matchedProps.join(', ');
+        if (notMatchedProps.length) {
+          this.params.operator += "\n    not matched properties: " + notMatchedProps.join(", ");
+        }
+        if (matchedProps.length) {
+          this.params.operator += "\n    matched properties: " + matchedProps.join(", ");
+        }
 
         this.assert(notMatchedProps.length === 0);
       } else {
@@ -158,12 +173,19 @@ module.exports = function(should, Assertion) {
    *
    * { a: 'a', b: 'a', c: 'a' }.should.matchEach(function(value) { value.should.be.eql('a') });
    */
-  Assertion.add('matchEach', function(other, description) {
-    this.params = {operator: 'to match each ' + i(other), message: description};
+  Assertion.add("matchEach", function(other, description) {
+    this.params = {
+      operator: "to match each " + i(other),
+      message: description
+    };
 
-    util.forEach(this.obj, function(value) {
-      should(value).match(other);
-    }, this);
+    forEach(
+      this.obj,
+      function(value) {
+        should(value).match(other);
+      },
+      this
+    );
   });
 
   /**
@@ -187,23 +209,28 @@ module.exports = function(should, Assertion) {
   *
   * { a: 'a', b: 'b', c: 'c' }.should.matchAny(function(value) { value.should.be.eql('a') });
   */
-  Assertion.add('matchAny', function(other, description) {
-    this.params = {operator: 'to match any ' + i(other), message: description};
+  Assertion.add("matchAny", function(other, description) {
+    this.params = {
+      operator: "to match any " + i(other),
+      message: description
+    };
 
-    this.assert(util.some(this.obj, function(value) {
-      try {
-        should(value).match(other);
-        return true;
-      } catch (e) {
-        if (e instanceof should.AssertionError) {
-          // Caught an AssertionError, return false to the iterator
-          return false;
+    this.assert(
+      some(this.obj, function(value) {
+        try {
+          should(value).match(other);
+          return true;
+        } catch (e) {
+          if (e instanceof should.AssertionError) {
+            // Caught an AssertionError, return false to the iterator
+            return false;
+          }
+          throw e;
         }
-        throw e;
-      }
-    }));
+      })
+    );
   });
 
-  Assertion.alias('matchAny', 'matchSome');
-  Assertion.alias('matchEach', 'matchEvery');
-};
+  Assertion.alias("matchAny", "matchSome");
+  Assertion.alias("matchEach", "matchEvery");
+}
