@@ -1,16 +1,19 @@
 /*
  * should.js - assertion library
  * Copyright(c) 2010-2013 TJ Holowaychuk <tj@vision-media.ca>
- * Copyright(c) 2013-2016 Denis Bardadym <bardadymchik@gmail.com>
+ * Copyright(c) 2013-2017 Denis Bardadym <bardadymchik@gmail.com>
  * MIT Licensed
  */
 
-var util = require('../util');
-var eql = require('should-equal');
+import { convertPropertyName } from "../util";
+import { hasOwnProperty } from "should-util";
+import { formatProp } from "../format";
+import { isEmpty, has as hasKey, get as getValue, size } from "should-type-adaptors";
+import eql from "should-equal";
 
 var aSlice = Array.prototype.slice;
 
-module.exports = function(should, Assertion) {
+export default function(should, Assertion) {
   var i = should.format;
   /**
    * Asserts given object has some descriptor. **On success it change given object to be value of property**.
@@ -24,80 +27,16 @@ module.exports = function(should, Assertion) {
    *
    * ({ a: 10 }).should.have.propertyWithDescriptor('a', { enumerable: true });
    */
-  Assertion.add('propertyWithDescriptor', function(name, desc) {
-    this.params = {actual: this.obj, operator: 'to have own property with descriptor ' + i(desc)};
+  Assertion.add("propertyWithDescriptor", function(name, desc) {
+    this.params = {
+      actual: this.obj,
+      operator: "to have own property with descriptor " + i(desc)
+    };
     var obj = this.obj;
     this.have.ownProperty(name);
     should(Object.getOwnPropertyDescriptor(Object(obj), name)).have.properties(desc);
   });
 
-  function processPropsArgs() {
-    var args = {};
-    if (arguments.length > 1) {
-      args.names = aSlice.call(arguments);
-    } else {
-      var arg = arguments[0];
-      if (typeof arg === 'string') {
-        args.names = [arg];
-      } else if (util.isIndexable(arg)) {
-        args.names = arg;
-      } else {
-        args.names = Object.keys(arg);
-        args.values = arg;
-      }
-    }
-    return args;
-  }
-
-
-  /**
-   * Asserts given object has enumerable property with optionally value. **On success it change given object to be value of property**.
-   *
-   * @name enumerable
-   * @memberOf Assertion
-   * @category assertion property
-   * @param {string} name Name of property
-   * @param {*} [val] Optional property value to check
-   * @example
-   *
-   * ({ a: 10 }).should.have.enumerable('a');
-   */
-  Assertion.add('enumerable', function(name, val) {
-    name = util.convertPropertyName(name);
-
-    this.params = {
-      operator: "to have enumerable property " + util.formatProp(name) + (arguments.length > 1 ? " equal to " + i(val): "")
-    };
-
-    var desc = { enumerable: true };
-    if (arguments.length > 1) desc.value = val;
-    this.have.propertyWithDescriptor(name, desc);
-  });
-
-  /**
-   * Asserts given object has enumerable properties
-   *
-   * @name enumerables
-   * @memberOf Assertion
-   * @category assertion property
-   * @param {Array|...string|Object} names Names of property
-   * @example
-   *
-   * ({ a: 10, b: 10 }).should.have.enumerables('a');
-   */
-  Assertion.add('enumerables', function(/*names*/) {
-    var args = processPropsArgs.apply(null, arguments);
-
-    this.params = {
-      operator: "to have enumerables " + args.names.map(util.formatProp)
-    };
-
-    var obj = this.obj;
-    args.names.forEach(function(name) {
-      should(obj).have.enumerable(name);
-    });
-  });
-
   /**
    * Asserts given object has property with optionally value. **On success it change given object to be value of property**.
    *
@@ -110,8 +49,8 @@ module.exports = function(should, Assertion) {
    *
    * ({ a: 10 }).should.have.property('a');
    */
-  Assertion.add('property', function(name, val) {
-    name = util.convertPropertyName(name);
+  Assertion.add("property", function(name, val) {
+    name = convertPropertyName(name);
     if (arguments.length > 1) {
       var p = {};
       p[name] = val;
@@ -135,12 +74,12 @@ module.exports = function(should, Assertion) {
    * ({ a: 10, b: 20 }).should.have.properties([ 'a' ]);
    * ({ a: 10, b: 20 }).should.have.properties({ b: 20 });
    */
-  Assertion.add('properties', function(names) {
+  Assertion.add("properties", function(names) {
     var values = {};
     if (arguments.length > 1) {
       names = aSlice.call(arguments);
     } else if (!Array.isArray(names)) {
-      if (typeof names == 'string' || typeof names == 'symbol') {
+      if (typeof names == "string" || typeof names == "symbol") {
         names = [names];
       } else {
         values = names;
@@ -148,30 +87,39 @@ module.exports = function(should, Assertion) {
       }
     }
 
-    var obj = Object(this.obj), missingProperties = [];
+    var obj = Object(this.obj),
+      missingProperties = [];
 
     //just enumerate properties and check if they all present
     names.forEach(function(name) {
-      if (!(name in obj)) missingProperties.push(util.formatProp(name));
+      if (!(name in obj)) {
+        missingProperties.push(formatProp(name));
+      }
     });
 
     var props = missingProperties;
     if (props.length === 0) {
-      props = names.map(util.formatProp);
+      props = names.map(formatProp);
     } else if (this.anyOne) {
-      props = names.filter(function(name) {
-        return missingProperties.indexOf(util.formatProp(name)) < 0;
-      }).map(util.formatProp);
+      props = names
+        .filter(function(name) {
+          return missingProperties.indexOf(formatProp(name)) < 0;
+        })
+        .map(formatProp);
     }
 
-    var operator = (props.length === 1 ?
-        'to have property ' : 'to have ' + (this.anyOne ? 'any of ' : '') + 'properties ') + props.join(', ');
+    var operator =
+      (props.length === 1
+        ? "to have property "
+        : "to have " + (this.anyOne ? "any of " : "") + "properties ") + props.join(", ");
 
-    this.params = {obj: this.obj, operator: operator};
+    this.params = { obj: this.obj, operator: operator };
 
     //check that all properties presented
     //or if we request one of them that at least one them presented
-    this.assert(missingProperties.length === 0 || (this.anyOne && missingProperties.length != names.length));
+    this.assert(
+      missingProperties.length === 0 || (this.anyOne && missingProperties.length != names.length)
+    );
 
     // check if values in object matched expected
     var valueCheckNames = Object.keys(values);
@@ -182,10 +130,10 @@ module.exports = function(should, Assertion) {
       // now check values, as there we have all properties
       valueCheckNames.forEach(function(name) {
         var value = values[name];
-        if (!eql(obj[name], value).result) {
-          wrongValues.push(util.formatProp(name) + ' of ' + i(value) + ' (got ' + i(obj[name]) + ')');
+        if (eql(obj[name], value).length !== 0) {
+          wrongValues.push(formatProp(name) + " of " + i(value) + " (got " + i(obj[name]) + ")");
         } else {
-          props.push(util.formatProp(name) + ' of ' + i(value));
+          props.push(formatProp(name) + " of " + i(value));
         }
       });
 
@@ -193,14 +141,18 @@ module.exports = function(should, Assertion) {
         props = wrongValues;
       }
 
-      operator = (props.length === 1 ?
-        'to have property ' : 'to have ' + (this.anyOne ? 'any of ' : '') + 'properties ') + props.join(', ');
+      operator =
+        (props.length === 1
+          ? "to have property "
+          : "to have " + (this.anyOne ? "any of " : "") + "properties ") + props.join(", ");
 
-      this.params = {obj: this.obj, operator: operator};
+      this.params = { obj: this.obj, operator: operator };
 
       //if there is no not matched values
       //or there is at least one matched
-      this.assert(wrongValues.length === 0 || (this.anyOne && wrongValues.length != valueCheckNames.length));
+      this.assert(
+        wrongValues.length === 0 || (this.anyOne && wrongValues.length != valueCheckNames.length)
+      );
     }
   });
 
@@ -217,13 +169,11 @@ module.exports = function(should, Assertion) {
    *
    * [1, 2].should.have.length(2);
    */
-  Assertion.add('length', function(n, description) {
-    this.have.property('length', n, description);
+  Assertion.add("length", function(n, description) {
+    this.have.property("length", n, description);
   });
 
-  Assertion.alias('length', 'lengthOf');
-
-  var hasOwnProperty = Object.prototype.hasOwnProperty;
+  Assertion.alias("length", "lengthOf");
 
   /**
    * Asserts given object has own property. **On success it change given object to be value of property**.
@@ -238,20 +188,20 @@ module.exports = function(should, Assertion) {
    *
    * ({ a: 10 }).should.have.ownProperty('a');
    */
-  Assertion.add('ownProperty', function(name, description) {
-    name = util.convertPropertyName(name);
+  Assertion.add("ownProperty", function(name, description) {
+    name = convertPropertyName(name);
     this.params = {
       actual: this.obj,
-      operator: 'to have own property ' + util.formatProp(name),
+      operator: "to have own property " + formatProp(name),
       message: description
     };
 
-    this.assert(hasOwnProperty.call(this.obj, name));
+    this.assert(hasOwnProperty(this.obj, name));
 
     this.obj = this.obj[name];
   });
 
-  Assertion.alias('ownProperty', 'hasOwnProperty');
+  Assertion.alias("ownProperty", "hasOwnProperty");
 
   /**
    * Asserts given object is empty. For strings, arrays and arguments it checks .length property, for objects it checks keys.
@@ -265,73 +215,95 @@ module.exports = function(should, Assertion) {
    * [].should.be.empty();
    * ({}).should.be.empty();
    */
-  Assertion.add('empty', function() {
-    this.params = {operator: 'to be empty'};
-
-    if (util.length(this.obj) !== void 0) {
-      should(this.obj).have.property('length', 0);
-    } else {
-      var obj = Object(this.obj); // wrap to reference for booleans and numbers
-      for (var prop in obj) {
-        should(this.obj).not.have.ownProperty(prop);
-      }
-    }
-  }, true);
+  Assertion.add(
+    "empty",
+    function() {
+      this.params = { operator: "to be empty" };
+      this.assert(isEmpty(this.obj));
+    },
+    true
+  );
 
   /**
-   * Asserts given object has exact keys. Compared to `properties`, `keys` does not accept Object as a argument.
+   * Asserts given object has such keys. Compared to `properties`, `keys` does not accept Object as a argument.
+   * When calling via .key current object in assertion changed to value of this key
    *
    * @name keys
    * @alias Assertion#key
    * @memberOf Assertion
    * @category assertion property
-   * @param {Array|...string} [keys] Keys to check
+   * @param {...*} keys Keys to check
    * @example
    *
    * ({ a: 10 }).should.have.keys('a');
    * ({ a: 10, b: 20 }).should.have.keys('a', 'b');
-   * ({ a: 10, b: 20 }).should.have.keys([ 'a', 'b' ]);
-   * ({}).should.have.keys();
+   * (new Map([[1, 2]])).should.have.key(1);
+   *
+   * json.should.have.only.keys('type', 'version')
    */
-  Assertion.add('keys', function(keys) {
-    if (arguments.length > 1) keys = aSlice.call(arguments);
-    else if (arguments.length === 1 && typeof keys === 'string') keys = [keys];
-    else if (arguments.length === 0) keys = [];
-
-    keys = keys.map(String);
+  Assertion.add("keys", function(keys) {
+    keys = aSlice.call(arguments);
 
     var obj = Object(this.obj);
 
     // first check if some keys are missing
-    var missingKeys = [];
-    keys.forEach(function(key) {
-      if (!hasOwnProperty.call(this.obj, key))
-        missingKeys.push(util.formatProp(key));
-    }, this);
-
-    // second check for extra keys
-    var extraKeys = [];
-    Object.keys(obj).forEach(function(key) {
-      if (keys.indexOf(key) < 0) {
-        extraKeys.push(util.formatProp(key));
-      }
+    var missingKeys = keys.filter(function(key) {
+      return !hasKey(obj, key);
     });
 
-    var verb = keys.length === 0 ? 'to be empty' :
-    'to have ' + (keys.length === 1 ? 'key ' : 'keys ');
+    var verb = "to have " + (this.onlyThis ? "only " : "") + (keys.length === 1 ? "key " : "keys ");
 
-    this.params = {operator: verb + keys.map(util.formatProp).join(', ')};
+    this.params = { operator: verb + keys.join(", ") };
 
-    if (missingKeys.length > 0)
-      this.params.operator += '\n\tmissing keys: ' + missingKeys.join(', ');
+    if (missingKeys.length > 0) {
+      this.params.operator += "\n\tmissing keys: " + missingKeys.join(", ");
+    }
 
-    if (extraKeys.length > 0)
-      this.params.operator += '\n\textra keys: ' + extraKeys.join(', ');
+    this.assert(missingKeys.length === 0);
 
-    this.assert(missingKeys.length === 0 && extraKeys.length === 0);
+    if (this.onlyThis) {
+      should(obj).have.size(keys.length);
+    }
   });
 
-  Assertion.alias("keys", "key");
+  Assertion.add("key", function(key) {
+    this.have.keys(key);
+    this.obj = getValue(this.obj, key);
+  });
+
+  /**
+   * Asserts given object has such value for given key
+   *
+   * @name value
+   * @memberOf Assertion
+   * @category assertion property
+   * @param {*} key Key to check
+   * @param {*} value Value to check
+   * @example
+   *
+   * ({ a: 10 }).should.have.value('a', 10);
+   * (new Map([[1, 2]])).should.have.value(1, 2);
+   */
+  Assertion.add("value", function(key, value) {
+    this.have.key(key).which.is.eql(value);
+  });
+
+  /**
+   * Asserts given object has such size.
+   *
+   * @name size
+   * @memberOf Assertion
+   * @category assertion property
+   * @param {number} s Size to check
+   * @example
+   *
+   * ({ a: 10 }).should.have.size(1);
+   * (new Map([[1, 2]])).should.have.size(1);
+   */
+  Assertion.add("size", function(s) {
+    this.params = { operator: "to have size " + s };
+    should(size(this.obj)).be.exactly(s);
+  });
 
   /**
    * Asserts given object has nested property in depth by path. **On success it change given object to be value of final property**.
@@ -344,14 +316,12 @@ module.exports = function(should, Assertion) {
    *
    * ({ a: {b: 10}}).should.have.propertyByPath('a', 'b').eql(10);
    */
-  Assertion.add('propertyByPath', function(properties) {
-    if (arguments.length > 1) properties = aSlice.call(arguments);
-    else if (arguments.length === 1 && typeof properties == 'string') properties = [properties];
-    else if (arguments.length === 0) properties = [];
+  Assertion.add("propertyByPath", function(properties) {
+    properties = aSlice.call(arguments);
 
-    var allProps = properties.map(util.formatProp);
+    var allProps = properties.map(formatProp);
 
-    properties = properties.map(String);
+    properties = properties.map(convertPropertyName);
 
     var obj = should(Object(this.obj));
 
@@ -360,13 +330,22 @@ module.exports = function(should, Assertion) {
     var currentProperty;
     while (properties.length) {
       currentProperty = properties.shift();
-      this.params = {operator: 'to have property by path ' + allProps.join(', ') + ' - failed on ' + util.formatProp(currentProperty)};
+      this.params = {
+        operator:
+          "to have property by path " +
+          allProps.join(", ") +
+          " - failed on " +
+          formatProp(currentProperty)
+      };
       obj = obj.have.property(currentProperty);
       foundProperties.push(currentProperty);
     }
 
-    this.params = {obj: this.obj, operator: 'to have property by path ' + allProps.join(', ')};
+    this.params = {
+      obj: this.obj,
+      operator: "to have property by path " + allProps.join(", ")
+    };
 
     this.obj = obj.obj;
   });
-};
+}
