@@ -1,11 +1,11 @@
 /*
  * should.js - assertion library
  * Copyright(c) 2010-2013 TJ Holowaychuk <tj@vision-media.ca>
- * Copyright(c) 2013-2016 Denis Bardadym <bardadymchik@gmail.com>
+ * Copyright(c) 2013-2017 Denis Bardadym <bardadymchik@gmail.com>
  * MIT Licensed
  */
 
-module.exports = function(should, Assertion) {
+export default function(should, Assertion) {
   /**
    * Assert given string starts with prefix
    * @name startWith
@@ -17,8 +17,11 @@ module.exports = function(should, Assertion) {
    *
    * 'abc'.should.startWith('a');
    */
-  Assertion.add('startWith', function(str, description) {
-    this.params = { operator: 'to start with ' + should.format(str), message: description };
+  Assertion.add("startWith", function(str, description) {
+    this.params = {
+      operator: "to start with " + should.format(str),
+      message: description
+    };
 
     this.assert(0 === this.obj.indexOf(str));
   });
@@ -34,9 +37,12 @@ module.exports = function(should, Assertion) {
    *
    * 'abca'.should.endWith('a');
    */
-  Assertion.add('endWith', function(str, description) {
-    this.params = { operator: 'to end with ' + should.format(str), message: description };
+  Assertion.add("endWith", function(str, description) {
+    this.params = {
+      operator: "to end with " + should.format(str),
+      message: description
+    };
 
     this.assert(this.obj.indexOf(str, this.obj.length - str.length) >= 0);
   });
-};
+}
