@@ -1,23 +1,24 @@
 /*
  * should.js - assertion library
  * Copyright(c) 2010-2013 TJ Holowaychuk <tj@vision-media.ca>
- * Copyright(c) 2013-2016 Denis Bardadym <bardadymchik@gmail.com>
+ * Copyright(c) 2013-2017 Denis Bardadym <bardadymchik@gmail.com>
  * MIT Licensed
  */
 
-var util = require('../util');
+import { functionName } from "../util";
 
-module.exports = function(should, Assertion) {
+export default function(should, Assertion) {
   /**
    * Assert given object is number
    * @name Number
    * @memberOf Assertion
    * @category assertion types
    */
-  Assertion.add('Number', function() {
-    this.params = {operator: 'to be a number'};
+  Assertion.add("Number", function() {
+    this.assertZeroArguments(arguments);
+    this.params = { operator: "to be a number" };
 
-    this.have.type('number');
+    this.have.type("number");
   });
 
   /**
@@ -27,13 +28,14 @@ module.exports = function(should, Assertion) {
    * @memberOf Assertion
    * @category assertion types
    */
-  Assertion.add('arguments', function() {
-    this.params = {operator: 'to be arguments'};
+  Assertion.add("arguments", function() {
+    this.assertZeroArguments(arguments);
+    this.params = { operator: "to be arguments" };
 
-    this.have.class('Arguments');
+    this.have.class("Arguments");
   });
 
-  Assertion.alias('arguments', 'Arguments');
+  Assertion.alias("arguments", "Arguments");
 
   /**
    * Assert given object has some type using `typeof`
@@ -43,8 +45,8 @@ module.exports = function(should, Assertion) {
    * @param {string} [description] Optional message
    * @category assertion types
    */
-  Assertion.add('type', function(type, description) {
-    this.params = {operator: 'to have type ' + type, message: description};
+  Assertion.add("type", function(type, description) {
+    this.params = { operator: "to have type " + type, message: description };
 
     should(typeof this.obj).be.exactly(type);
   });
@@ -58,13 +60,16 @@ module.exports = function(should, Assertion) {
    * @param {string} [description] Optional message
    * @category assertion types
    */
-  Assertion.add('instanceof', function(constructor, description) {
-    this.params = {operator: 'to be an instance of ' + util.functionName(constructor), message: description};
+  Assertion.add("instanceof", function(constructor, description) {
+    this.params = {
+      operator: "to be an instance of " + functionName(constructor),
+      message: description
+    };
 
     this.assert(Object(this.obj) instanceof constructor);
   });
 
-  Assertion.alias('instanceof', 'instanceOf');
+  Assertion.alias("instanceof", "instanceOf");
 
   /**
    * Assert given object is function
@@ -72,10 +77,11 @@ module.exports = function(should, Assertion) {
    * @memberOf Assertion
    * @category assertion types
    */
-  Assertion.add('Function', function() {
-    this.params = {operator: 'to be a function'};
+  Assertion.add("Function", function() {
+    this.assertZeroArguments(arguments);
+    this.params = { operator: "to be a function" };
 
-    this.have.type('function');
+    this.have.type("function");
   });
 
   /**
@@ -84,10 +90,11 @@ module.exports = function(should, Assertion) {
    * @memberOf Assertion
    * @category assertion types
    */
-  Assertion.add('Object', function() {
-    this.params = {operator: 'to be an object'};
+  Assertion.add("Object", function() {
+    this.assertZeroArguments(arguments);
+    this.params = { operator: "to be an object" };
 
-    this.is.not.null().and.have.type('object');
+    this.is.not.null().and.have.type("object");
   });
 
   /**
@@ -96,10 +103,11 @@ module.exports = function(should, Assertion) {
    * @memberOf Assertion
    * @category assertion types
    */
-  Assertion.add('String', function() {
-    this.params = {operator: 'to be a string'};
+  Assertion.add("String", function() {
+    this.assertZeroArguments(arguments);
+    this.params = { operator: "to be a string" };
 
-    this.have.type('string');
+    this.have.type("string");
   });
 
   /**
@@ -108,10 +116,11 @@ module.exports = function(should, Assertion) {
    * @memberOf Assertion
    * @category assertion types
    */
-  Assertion.add('Array', function() {
-    this.params = {operator: 'to be an array'};
+  Assertion.add("Array", function() {
+    this.assertZeroArguments(arguments);
+    this.params = { operator: "to be an array" };
 
-    this.have.class('Array');
+    this.have.class("Array");
   });
 
   /**
@@ -120,10 +129,11 @@ module.exports = function(should, Assertion) {
    * @memberOf Assertion
    * @category assertion types
    */
-  Assertion.add('Boolean', function() {
-    this.params = {operator: 'to be a boolean'};
+  Assertion.add("Boolean", function() {
+    this.assertZeroArguments(arguments);
+    this.params = { operator: "to be a boolean" };
 
-    this.have.type('boolean');
+    this.have.type("boolean");
   });
 
   /**
@@ -132,8 +142,9 @@ module.exports = function(should, Assertion) {
    * @memberOf Assertion
    * @category assertion types
    */
-  Assertion.add('Error', function() {
-    this.params = {operator: 'to be an error'};
+  Assertion.add("Error", function() {
+    this.assertZeroArguments(arguments);
+    this.params = { operator: "to be an error" };
 
     this.have.instanceOf(Error);
   });
@@ -144,8 +155,9 @@ module.exports = function(should, Assertion) {
    * @memberOf Assertion
    * @category assertion types
    */
-  Assertion.add('Date', function() {
-    this.params = {operator: 'to be a date'};
+  Assertion.add("Date", function() {
+    this.assertZeroArguments(arguments);
+    this.params = { operator: "to be a date" };
 
     this.have.instanceOf(Date);
   });
@@ -157,13 +169,14 @@ module.exports = function(should, Assertion) {
    * @memberOf Assertion
    * @category assertion types
    */
-  Assertion.add('null', function() {
-    this.params = {operator: 'to be null'};
+  Assertion.add("null", function() {
+    this.assertZeroArguments(arguments);
+    this.params = { operator: "to be null" };
 
     this.assert(this.obj === null);
   });
 
-  Assertion.alias('null', 'Null');
+  Assertion.alias("null", "Null");
 
   /**
    * Assert given object has some internal [[Class]], via Object.prototype.toString call
@@ -172,13 +185,13 @@ module.exports = function(should, Assertion) {
    * @memberOf Assertion
    * @category assertion types
    */
-  Assertion.add('class', function(cls) {
-    this.params = {operator: 'to have [[Class]] ' + cls};
+  Assertion.add("class", function(cls) {
+    this.params = { operator: "to have [[Class]] " + cls };
 
-    this.assert(Object.prototype.toString.call(this.obj) === '[object ' + cls + ']');
+    this.assert(Object.prototype.toString.call(this.obj) === "[object " + cls + "]");
   });
 
-  Assertion.alias('class', 'Class');
+  Assertion.alias("class", "Class");
 
   /**
    * Assert given object is undefined
@@ -187,13 +200,14 @@ module.exports = function(should, Assertion) {
    * @memberOf Assertion
    * @category assertion types
    */
-  Assertion.add('undefined', function() {
-    this.params = {operator: 'to be undefined'};
+  Assertion.add("undefined", function() {
+    this.assertZeroArguments(arguments);
+    this.params = { operator: "to be undefined" };
 
     this.assert(this.obj === void 0);
   });
 
-  Assertion.alias('undefined', 'Undefined');
+  Assertion.alias("undefined", "Undefined");
 
   /**
    * Assert given object supports es6 iterable protocol (just check
@@ -202,10 +216,13 @@ module.exports = function(should, Assertion) {
    * @memberOf Assertion
    * @category assertion es6
    */
-  Assertion.add('iterable', function() {
-    this.params = {operator: 'to be iterable'};
+  Assertion.add("iterable", function() {
+    this.assertZeroArguments(arguments);
+    this.params = { operator: "to be iterable" };
 
-    should(this.obj).have.property(Symbol.iterator).which.is.a.Function();
+    should(this.obj)
+      .have.property(Symbol.iterator)
+      .which.is.a.Function();
   });
 
   /**
@@ -215,10 +232,13 @@ module.exports = function(should, Assertion) {
    * @memberOf Assertion
    * @category assertion es6
    */
-  Assertion.add('iterator', function() {
-    this.params = {operator: 'to be iterator'};
+  Assertion.add("iterator", function() {
+    this.assertZeroArguments(arguments);
+    this.params = { operator: "to be iterator" };
 
-    should(this.obj).have.property('next').which.is.a.Function();
+    should(this.obj)
+      .have.property("next")
+      .which.is.a.Function();
   });
 
   /**
@@ -227,11 +247,10 @@ module.exports = function(should, Assertion) {
    * @memberOf Assertion
    * @category assertion es6
    */
-  Assertion.add('generator', function() {
-    this.params = {operator: 'to be generator'};
+  Assertion.add("generator", function() {
+    this.assertZeroArguments(arguments);
+    this.params = { operator: "to be generator" };
 
-    should(this.obj).be.iterable
-      .and.iterator
-      .and.it.is.equal(this.obj[Symbol.iterator]());
+    should(this.obj).be.iterable.and.iterator.and.it.is.equal(this.obj[Symbol.iterator]());
   });
-};
+}
