@@ -1,12 +1,31 @@
 /*
  * should.js - assertion library
  * Copyright(c) 2010-2013 TJ Holowaychuk <tj@vision-media.ca>
- * Copyright(c) 2013-2016 Denis Bardadym <bardadymchik@gmail.com>
+ * Copyright(c) 2013-2017 Denis Bardadym <bardadymchik@gmail.com>
  * MIT Licensed
  */
+import t from "should-type";
+import eq from "should-equal";
+import defaultFormat from "should-format";
 
+import { isWrapperType } from "./util";
+import { format } from "./format";
+import AssertionError from "./assertion-error";
+import { Assertion } from "./assertion";
+import config from "./config";
 
-var util = require('./util');
+import assertExtensions from "./ext/assert";
+import chainAssertions from "./ext/chain";
+import booleanAssertions from "./ext/bool";
+import numberAssertions from "./ext/number";
+import typeAssertions from "./ext/type";
+import equalityAssertions from "./ext/eql";
+import promiseAssertions from "./ext/promise";
+import stringAssertions from "./ext/string";
+import containAssertions from "./ext/contain";
+import propertyAssertions from "./ext/property";
+import errorAssertions from "./ext/error";
+import matchingAssertions from "./ext/match";
 
 /**
  * Our function should
@@ -19,15 +38,19 @@ var util = require('./util');
  * should('abc').be.a.String();
  */
 function should(obj) {
-  return (new should.Assertion(obj));
+  return new Assertion(obj);
 }
 
-should.AssertionError = require('./assertion-error');
-should.Assertion = require('./assertion');
+should.AssertionError = AssertionError;
+should.Assertion = Assertion;
 
-should.format = util.format;
-should.type = require('should-type');
-should.util = util;
+// exposing modules dirty way
+should.modules = {
+  format: defaultFormat,
+  type: t,
+  equal: eq
+};
+should.format = format;
 
 /**
  * Object with configuration.
@@ -51,10 +74,10 @@ should.util = util;
  * a.should.be.eql(b);
  * //throws AssertionError: expected { a: 10 } to equal { a: 10 } (because A and B have different prototypes)
  */
-should.config = require('./config');
+should.config = config;
 
 // Expose should to external world.
-exports = module.exports = should;
+export default should;
 
 /**
  * Allow to extend given prototype with should property using given name. This getter will **unwrap** all standard wrappers like `Number`, `Boolean`, `String`.
@@ -77,16 +100,15 @@ exports = module.exports = should;
  * should.not.exist(Object.prototype.must);
  */
 should.extend = function(propertyName, proto) {
-  propertyName = propertyName || 'should';
+  propertyName = propertyName || "should";
   proto = proto || Object.prototype;
 
   var prevDescriptor = Object.getOwnPropertyDescriptor(proto, propertyName);
 
   Object.defineProperty(proto, propertyName, {
-    set: function() {
-    },
+    set: function() {},
     get: function() {
-      return should(util.isWrapperType(this) ? this.valueOf() : this);
+      return should(isWrapperType(this) ? this.valueOf() : this);
     },
     configurable: true
   });
@@ -149,15 +171,15 @@ should.use = function(f) {
 };
 
 should
-  .use(require('./ext/assert'))
-  .use(require('./ext/chain'))
-  .use(require('./ext/bool'))
-  .use(require('./ext/number'))
-  .use(require('./ext/eql'))
-  .use(require('./ext/type'))
-  .use(require('./ext/string'))
-  .use(require('./ext/property'))
-  .use(require('./ext/error'))
-  .use(require('./ext/match'))
-  .use(require('./ext/contain'))
-  .use(require('./ext/promise'));
+  .use(assertExtensions)
+  .use(chainAssertions)
+  .use(booleanAssertions)
+  .use(numberAssertions)
+  .use(equalityAssertions)
+  .use(typeAssertions)
+  .use(stringAssertions)
+  .use(propertyAssertions)
+  .use(errorAssertions)
+  .use(matchingAssertions)
+  .use(containAssertions)
+  .use(promiseAssertions);
